# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/buildNanoGPT',
                'doc_host': 'https://hdocmsu.github.io',
                'git_url': 'https://github.com/hdocmsu/buildNanoGPT/',
                'lib_path': 'buildNanoGPT'},
  'syms': { 'buildNanoGPT.nanogpt1': { 'buildNanoGPT.nanogpt1.Block': ('Dev_Notes/nanogpt01.html#block', 'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.Block.__init__': ( 'Dev_Notes/nanogpt01.html#block.__init__',
                                                                                 'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.Block.forward': ( 'Dev_Notes/nanogpt01.html#block.forward',
                                                                                'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.CausalSelfAttention': ( 'Dev_Notes/nanogpt01.html#causalselfattention',
                                                                                      'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.CausalSelfAttention.__init__': ( 'Dev_Notes/nanogpt01.html#causalselfattention.__init__',
                                                                                               'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.CausalSelfAttention.forward': ( 'Dev_Notes/nanogpt01.html#causalselfattention.forward',
                                                                                              'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.GPT': ('Dev_Notes/nanogpt01.html#gpt', 'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.GPT.__init__': ( 'Dev_Notes/nanogpt01.html#gpt.__init__',
                                                                               'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.GPT.forward': ( 'Dev_Notes/nanogpt01.html#gpt.forward',
                                                                              'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.GPTConfig': ( 'Dev_Notes/nanogpt01.html#gptconfig',
                                                                            'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.MLP': ('Dev_Notes/nanogpt01.html#mlp', 'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.MLP.__init__': ( 'Dev_Notes/nanogpt01.html#mlp.__init__',
                                                                               'buildNanoGPT/nanogpt1.py'),
                                       'buildNanoGPT.nanogpt1.MLP.forward': ( 'Dev_Notes/nanogpt01.html#mlp.forward',
                                                                              'buildNanoGPT/nanogpt1.py')},
            'buildNanoGPT.nanogpt10': { 'buildNanoGPT.nanogpt10.Block': ('nanoGPT_PyPI/nanogpt10.html#block', 'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.Block.__init__': ( 'nanoGPT_PyPI/nanogpt10.html#block.__init__',
                                                                                   'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.Block.forward': ( 'nanoGPT_PyPI/nanogpt10.html#block.forward',
                                                                                  'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.CausalSelfAttention': ( 'nanoGPT_PyPI/nanogpt10.html#causalselfattention',
                                                                                        'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.CausalSelfAttention.__init__': ( 'nanoGPT_PyPI/nanogpt10.html#causalselfattention.__init__',
                                                                                                 'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.CausalSelfAttention.forward': ( 'nanoGPT_PyPI/nanogpt10.html#causalselfattention.forward',
                                                                                                'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.DataLoaderLite': ( 'nanoGPT_PyPI/nanogpt10.html#dataloaderlite',
                                                                                   'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.DataLoaderLite.__init__': ( 'nanoGPT_PyPI/nanogpt10.html#dataloaderlite.__init__',
                                                                                            'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.DataLoaderLite.next_batch': ( 'nanoGPT_PyPI/nanogpt10.html#dataloaderlite.next_batch',
                                                                                              'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.DataLoaderLite.reset': ( 'nanoGPT_PyPI/nanogpt10.html#dataloaderlite.reset',
                                                                                         'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.GPT': ('nanoGPT_PyPI/nanogpt10.html#gpt', 'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.GPT.__init__': ( 'nanoGPT_PyPI/nanogpt10.html#gpt.__init__',
                                                                                 'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.GPT._init_weights': ( 'nanoGPT_PyPI/nanogpt10.html#gpt._init_weights',
                                                                                      'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.GPT.configure_optimizers': ( 'nanoGPT_PyPI/nanogpt10.html#gpt.configure_optimizers',
                                                                                             'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.GPT.forward': ( 'nanoGPT_PyPI/nanogpt10.html#gpt.forward',
                                                                                'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.GPT.from_pretrained': ( 'nanoGPT_PyPI/nanogpt10.html#gpt.from_pretrained',
                                                                                        'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.GPTConfig': ( 'nanoGPT_PyPI/nanogpt10.html#gptconfig',
                                                                              'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.MLP': ('nanoGPT_PyPI/nanogpt10.html#mlp', 'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.MLP.__init__': ( 'nanoGPT_PyPI/nanogpt10.html#mlp.__init__',
                                                                                 'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.MLP.forward': ( 'nanoGPT_PyPI/nanogpt10.html#mlp.forward',
                                                                                'buildNanoGPT/nanogpt10.py'),
                                        'buildNanoGPT.nanogpt10.load_tokens': ( 'nanoGPT_PyPI/nanogpt10.html#load_tokens',
                                                                                'buildNanoGPT/nanogpt10.py')},
            'buildNanoGPT.nanogpt2': { 'buildNanoGPT.nanogpt2.Block': ('Dev_Notes/nanogpt02.html#block', 'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.Block.__init__': ( 'Dev_Notes/nanogpt02.html#block.__init__',
                                                                                 'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.Block.forward': ( 'Dev_Notes/nanogpt02.html#block.forward',
                                                                                'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.CausalSelfAttention': ( 'Dev_Notes/nanogpt02.html#causalselfattention',
                                                                                      'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.CausalSelfAttention.__init__': ( 'Dev_Notes/nanogpt02.html#causalselfattention.__init__',
                                                                                               'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.CausalSelfAttention.forward': ( 'Dev_Notes/nanogpt02.html#causalselfattention.forward',
                                                                                              'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.GPT': ('Dev_Notes/nanogpt02.html#gpt', 'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.GPT.__init__': ( 'Dev_Notes/nanogpt02.html#gpt.__init__',
                                                                               'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.GPT.from_pretrained': ( 'Dev_Notes/nanogpt02.html#gpt.from_pretrained',
                                                                                      'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.GPTConfig': ( 'Dev_Notes/nanogpt02.html#gptconfig',
                                                                            'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.MLP': ('Dev_Notes/nanogpt02.html#mlp', 'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.MLP.__init__': ( 'Dev_Notes/nanogpt02.html#mlp.__init__',
                                                                               'buildNanoGPT/nanogpt2.py'),
                                       'buildNanoGPT.nanogpt2.MLP.forward': ( 'Dev_Notes/nanogpt02.html#mlp.forward',
                                                                              'buildNanoGPT/nanogpt2.py')},
            'buildNanoGPT.nanogpt3': { 'buildNanoGPT.nanogpt3.Block': ('Dev_Notes/nanogpt03.html#block', 'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.Block.__init__': ( 'Dev_Notes/nanogpt03.html#block.__init__',
                                                                                 'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.Block.forward': ( 'Dev_Notes/nanogpt03.html#block.forward',
                                                                                'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.CausalSelfAttention': ( 'Dev_Notes/nanogpt03.html#causalselfattention',
                                                                                      'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.CausalSelfAttention.__init__': ( 'Dev_Notes/nanogpt03.html#causalselfattention.__init__',
                                                                                               'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.CausalSelfAttention.forward': ( 'Dev_Notes/nanogpt03.html#causalselfattention.forward',
                                                                                              'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.GPT': ('Dev_Notes/nanogpt03.html#gpt', 'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.GPT.__init__': ( 'Dev_Notes/nanogpt03.html#gpt.__init__',
                                                                               'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.GPT.forward': ( 'Dev_Notes/nanogpt03.html#gpt.forward',
                                                                              'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.GPT.from_pretrained': ( 'Dev_Notes/nanogpt03.html#gpt.from_pretrained',
                                                                                      'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.GPTConfig': ( 'Dev_Notes/nanogpt03.html#gptconfig',
                                                                            'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.MLP': ('Dev_Notes/nanogpt03.html#mlp', 'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.MLP.__init__': ( 'Dev_Notes/nanogpt03.html#mlp.__init__',
                                                                               'buildNanoGPT/nanogpt3.py'),
                                       'buildNanoGPT.nanogpt3.MLP.forward': ( 'Dev_Notes/nanogpt03.html#mlp.forward',
                                                                              'buildNanoGPT/nanogpt3.py')},
            'buildNanoGPT.nanogpt4': { 'buildNanoGPT.nanogpt4.Block': ('Dev_Notes/nanogpt04.html#block', 'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.Block.__init__': ( 'Dev_Notes/nanogpt04.html#block.__init__',
                                                                                 'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.Block.forward': ( 'Dev_Notes/nanogpt04.html#block.forward',
                                                                                'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.CausalSelfAttention': ( 'Dev_Notes/nanogpt04.html#causalselfattention',
                                                                                      'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.CausalSelfAttention.__init__': ( 'Dev_Notes/nanogpt04.html#causalselfattention.__init__',
                                                                                               'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.CausalSelfAttention.forward': ( 'Dev_Notes/nanogpt04.html#causalselfattention.forward',
                                                                                              'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.GPT': ('Dev_Notes/nanogpt04.html#gpt', 'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.GPT.__init__': ( 'Dev_Notes/nanogpt04.html#gpt.__init__',
                                                                               'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.GPT.forward': ( 'Dev_Notes/nanogpt04.html#gpt.forward',
                                                                              'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.GPT.from_pretrained': ( 'Dev_Notes/nanogpt04.html#gpt.from_pretrained',
                                                                                      'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.GPTConfig': ( 'Dev_Notes/nanogpt04.html#gptconfig',
                                                                            'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.MLP': ('Dev_Notes/nanogpt04.html#mlp', 'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.MLP.__init__': ( 'Dev_Notes/nanogpt04.html#mlp.__init__',
                                                                               'buildNanoGPT/nanogpt4.py'),
                                       'buildNanoGPT.nanogpt4.MLP.forward': ( 'Dev_Notes/nanogpt04.html#mlp.forward',
                                                                              'buildNanoGPT/nanogpt4.py')},
            'buildNanoGPT.nanogpt5': { 'buildNanoGPT.nanogpt5.Block': ('Dev_Notes/nanogpt05.html#block', 'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.Block.__init__': ( 'Dev_Notes/nanogpt05.html#block.__init__',
                                                                                 'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.Block.forward': ( 'Dev_Notes/nanogpt05.html#block.forward',
                                                                                'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.CausalSelfAttention': ( 'Dev_Notes/nanogpt05.html#causalselfattention',
                                                                                      'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.CausalSelfAttention.__init__': ( 'Dev_Notes/nanogpt05.html#causalselfattention.__init__',
                                                                                               'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.CausalSelfAttention.forward': ( 'Dev_Notes/nanogpt05.html#causalselfattention.forward',
                                                                                              'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.DataLoaderLite': ( 'Dev_Notes/nanogpt05.html#dataloaderlite',
                                                                                 'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.DataLoaderLite.__init__': ( 'Dev_Notes/nanogpt05.html#dataloaderlite.__init__',
                                                                                          'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.DataLoaderLite.next_batch': ( 'Dev_Notes/nanogpt05.html#dataloaderlite.next_batch',
                                                                                            'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.GPT': ('Dev_Notes/nanogpt05.html#gpt', 'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.GPT.__init__': ( 'Dev_Notes/nanogpt05.html#gpt.__init__',
                                                                               'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.GPT._init_weights': ( 'Dev_Notes/nanogpt05.html#gpt._init_weights',
                                                                                    'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.GPT.forward': ( 'Dev_Notes/nanogpt05.html#gpt.forward',
                                                                              'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.GPT.from_pretrained': ( 'Dev_Notes/nanogpt05.html#gpt.from_pretrained',
                                                                                      'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.GPTConfig': ( 'Dev_Notes/nanogpt05.html#gptconfig',
                                                                            'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.MLP': ('Dev_Notes/nanogpt05.html#mlp', 'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.MLP.__init__': ( 'Dev_Notes/nanogpt05.html#mlp.__init__',
                                                                               'buildNanoGPT/nanogpt5.py'),
                                       'buildNanoGPT.nanogpt5.MLP.forward': ( 'Dev_Notes/nanogpt05.html#mlp.forward',
                                                                              'buildNanoGPT/nanogpt5.py')},
            'buildNanoGPT.nanogpt6': { 'buildNanoGPT.nanogpt6.Block': ('Dev_Notes/nanogpt06.html#block', 'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.Block.__init__': ( 'Dev_Notes/nanogpt06.html#block.__init__',
                                                                                 'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.Block.forward': ( 'Dev_Notes/nanogpt06.html#block.forward',
                                                                                'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.CausalSelfAttention': ( 'Dev_Notes/nanogpt06.html#causalselfattention',
                                                                                      'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.CausalSelfAttention.__init__': ( 'Dev_Notes/nanogpt06.html#causalselfattention.__init__',
                                                                                               'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.CausalSelfAttention.forward': ( 'Dev_Notes/nanogpt06.html#causalselfattention.forward',
                                                                                              'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.DataLoaderLite': ( 'Dev_Notes/nanogpt06.html#dataloaderlite',
                                                                                 'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.DataLoaderLite.__init__': ( 'Dev_Notes/nanogpt06.html#dataloaderlite.__init__',
                                                                                          'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.DataLoaderLite.next_batch': ( 'Dev_Notes/nanogpt06.html#dataloaderlite.next_batch',
                                                                                            'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.GPT': ('Dev_Notes/nanogpt06.html#gpt', 'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.GPT.__init__': ( 'Dev_Notes/nanogpt06.html#gpt.__init__',
                                                                               'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.GPT._init_weights': ( 'Dev_Notes/nanogpt06.html#gpt._init_weights',
                                                                                    'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.GPT.forward': ( 'Dev_Notes/nanogpt06.html#gpt.forward',
                                                                              'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.GPT.from_pretrained': ( 'Dev_Notes/nanogpt06.html#gpt.from_pretrained',
                                                                                      'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.GPTConfig': ( 'Dev_Notes/nanogpt06.html#gptconfig',
                                                                            'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.MLP': ('Dev_Notes/nanogpt06.html#mlp', 'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.MLP.__init__': ( 'Dev_Notes/nanogpt06.html#mlp.__init__',
                                                                               'buildNanoGPT/nanogpt6.py'),
                                       'buildNanoGPT.nanogpt6.MLP.forward': ( 'Dev_Notes/nanogpt06.html#mlp.forward',
                                                                              'buildNanoGPT/nanogpt6.py')},
            'buildNanoGPT.nanogpt7': { 'buildNanoGPT.nanogpt7.Block': ('Dev_Notes/nanogpt07.html#block', 'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.Block.__init__': ( 'Dev_Notes/nanogpt07.html#block.__init__',
                                                                                 'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.Block.forward': ( 'Dev_Notes/nanogpt07.html#block.forward',
                                                                                'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.CausalSelfAttention': ( 'Dev_Notes/nanogpt07.html#causalselfattention',
                                                                                      'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.CausalSelfAttention.__init__': ( 'Dev_Notes/nanogpt07.html#causalselfattention.__init__',
                                                                                               'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.CausalSelfAttention.forward': ( 'Dev_Notes/nanogpt07.html#causalselfattention.forward',
                                                                                              'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.DataLoaderLite': ( 'Dev_Notes/nanogpt07.html#dataloaderlite',
                                                                                 'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.DataLoaderLite.__init__': ( 'Dev_Notes/nanogpt07.html#dataloaderlite.__init__',
                                                                                          'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.DataLoaderLite.next_batch': ( 'Dev_Notes/nanogpt07.html#dataloaderlite.next_batch',
                                                                                            'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.GPT': ('Dev_Notes/nanogpt07.html#gpt', 'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.GPT.__init__': ( 'Dev_Notes/nanogpt07.html#gpt.__init__',
                                                                               'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.GPT._init_weights': ( 'Dev_Notes/nanogpt07.html#gpt._init_weights',
                                                                                    'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.GPT.configure_optimizers': ( 'Dev_Notes/nanogpt07.html#gpt.configure_optimizers',
                                                                                           'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.GPT.forward': ( 'Dev_Notes/nanogpt07.html#gpt.forward',
                                                                              'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.GPT.from_pretrained': ( 'Dev_Notes/nanogpt07.html#gpt.from_pretrained',
                                                                                      'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.GPTConfig': ( 'Dev_Notes/nanogpt07.html#gptconfig',
                                                                            'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.MLP': ('Dev_Notes/nanogpt07.html#mlp', 'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.MLP.__init__': ( 'Dev_Notes/nanogpt07.html#mlp.__init__',
                                                                               'buildNanoGPT/nanogpt7.py'),
                                       'buildNanoGPT.nanogpt7.MLP.forward': ( 'Dev_Notes/nanogpt07.html#mlp.forward',
                                                                              'buildNanoGPT/nanogpt7.py')},
            'buildNanoGPT.nanogpt8': { 'buildNanoGPT.nanogpt8.Block': ('Dev_Notes/nanogpt08.html#block', 'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.Block.__init__': ( 'Dev_Notes/nanogpt08.html#block.__init__',
                                                                                 'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.Block.forward': ( 'Dev_Notes/nanogpt08.html#block.forward',
                                                                                'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.CausalSelfAttention': ( 'Dev_Notes/nanogpt08.html#causalselfattention',
                                                                                      'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.CausalSelfAttention.__init__': ( 'Dev_Notes/nanogpt08.html#causalselfattention.__init__',
                                                                                               'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.CausalSelfAttention.forward': ( 'Dev_Notes/nanogpt08.html#causalselfattention.forward',
                                                                                              'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.DataLoaderLite': ( 'Dev_Notes/nanogpt08.html#dataloaderlite',
                                                                                 'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.DataLoaderLite.__init__': ( 'Dev_Notes/nanogpt08.html#dataloaderlite.__init__',
                                                                                          'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.DataLoaderLite.next_batch': ( 'Dev_Notes/nanogpt08.html#dataloaderlite.next_batch',
                                                                                            'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.GPT': ('Dev_Notes/nanogpt08.html#gpt', 'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.GPT.__init__': ( 'Dev_Notes/nanogpt08.html#gpt.__init__',
                                                                               'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.GPT._init_weights': ( 'Dev_Notes/nanogpt08.html#gpt._init_weights',
                                                                                    'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.GPT.configure_optimizers': ( 'Dev_Notes/nanogpt08.html#gpt.configure_optimizers',
                                                                                           'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.GPT.forward': ( 'Dev_Notes/nanogpt08.html#gpt.forward',
                                                                              'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.GPT.from_pretrained': ( 'Dev_Notes/nanogpt08.html#gpt.from_pretrained',
                                                                                      'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.GPTConfig': ( 'Dev_Notes/nanogpt08.html#gptconfig',
                                                                            'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.MLP': ('Dev_Notes/nanogpt08.html#mlp', 'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.MLP.__init__': ( 'Dev_Notes/nanogpt08.html#mlp.__init__',
                                                                               'buildNanoGPT/nanogpt8.py'),
                                       'buildNanoGPT.nanogpt8.MLP.forward': ( 'Dev_Notes/nanogpt08.html#mlp.forward',
                                                                              'buildNanoGPT/nanogpt8.py')},
            'buildNanoGPT.nanogpt9': { 'buildNanoGPT.nanogpt9.Block': ('Dev_Notes/nanogpt09.html#block', 'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.Block.__init__': ( 'Dev_Notes/nanogpt09.html#block.__init__',
                                                                                 'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.Block.forward': ( 'Dev_Notes/nanogpt09.html#block.forward',
                                                                                'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.CausalSelfAttention': ( 'Dev_Notes/nanogpt09.html#causalselfattention',
                                                                                      'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.CausalSelfAttention.__init__': ( 'Dev_Notes/nanogpt09.html#causalselfattention.__init__',
                                                                                               'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.CausalSelfAttention.forward': ( 'Dev_Notes/nanogpt09.html#causalselfattention.forward',
                                                                                              'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.DataLoaderLite': ( 'Dev_Notes/nanogpt09.html#dataloaderlite',
                                                                                 'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.DataLoaderLite.__init__': ( 'Dev_Notes/nanogpt09.html#dataloaderlite.__init__',
                                                                                          'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.DataLoaderLite.next_batch': ( 'Dev_Notes/nanogpt09.html#dataloaderlite.next_batch',
                                                                                            'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.DataLoaderLite.reset': ( 'Dev_Notes/nanogpt09.html#dataloaderlite.reset',
                                                                                       'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.GPT': ('Dev_Notes/nanogpt09.html#gpt', 'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.GPT.__init__': ( 'Dev_Notes/nanogpt09.html#gpt.__init__',
                                                                               'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.GPT._init_weights': ( 'Dev_Notes/nanogpt09.html#gpt._init_weights',
                                                                                    'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.GPT.configure_optimizers': ( 'Dev_Notes/nanogpt09.html#gpt.configure_optimizers',
                                                                                           'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.GPT.forward': ( 'Dev_Notes/nanogpt09.html#gpt.forward',
                                                                              'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.GPT.from_pretrained': ( 'Dev_Notes/nanogpt09.html#gpt.from_pretrained',
                                                                                      'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.GPTConfig': ( 'Dev_Notes/nanogpt09.html#gptconfig',
                                                                            'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.MLP': ('Dev_Notes/nanogpt09.html#mlp', 'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.MLP.__init__': ( 'Dev_Notes/nanogpt09.html#mlp.__init__',
                                                                               'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.MLP.forward': ( 'Dev_Notes/nanogpt09.html#mlp.forward',
                                                                              'buildNanoGPT/nanogpt9.py'),
                                       'buildNanoGPT.nanogpt9.load_tokens': ( 'Dev_Notes/nanogpt09.html#load_tokens',
                                                                              'buildNanoGPT/nanogpt9.py')}}}
